Glossary
--------

floating-point:
    A type of variable (or value) that can contain fractions as well as
    integers. There are a few floating-point types in C++; the one we
    use in this book is double.

initialization:
    A statement that declares a new variable and assigns a value to it
    at the same time.

function:
    A named sequence of statements that performs some useful function.
    Functions may or may not take parameters, and may or may not produce
    a result.

parameter:
    A piece of information you provide in order to call a function.
    Parameters are like variables in the sense that they contain values
    and have types.

argument:
    A value that you provide when you call a function. This value must
    have the same type as the corresponding parameter.

call:
    Cause a function to be executed.


.. dragndrop:: chapter_three_glossary_one
    :feedback: Try again!
    :match_1: floating-point|||A type of value that can contain fractions as well as integers.
    :match_2: initialization|||A statement that declares a new variable and assigns a value to it.
    :match_3: call|||Causes a function to be executed.


.. dragndrop:: chapter_three_glossary_two
    :feedback: Try again!
    :match_1: function|||A named sequence of statements that performs some useful function.
    :match_2: parameter|||A piece of information you provide in order to call a function.
    :match_3: argument|||A value that you provide when you call a function.

